@@ -23,13 +23,15 @@ class BigQueryDBStream(dbstream.DBStream):
                  client_id,
                  google_auth: GoogleAuthentication,
                  dataset_location=None,
-                 tmp_folder_path="./"):
+                 tmp_folder_path="./",
+                 id_info='dck'):
         super().__init__(instance_name, client_id=client_id)
         self.instance_type_prefix = "BIGQ"
         self.google_auth = google_auth
         self.ssh_init_port = 6543
         self.dataset_location = dataset_location
         self.tmp_folder_path = tmp_folder_path
+        self.id_info = id_info
 
     def connection(self):
         try:
@@ -63,7 +65,7 @@ class BigQueryDBStream(dbstream.DBStream):
             result = cursor.fetchall()
         except AttributeError:
             result = None
-        else:
+        except:
             raise
         cursor.close()
         con.close()
@@ -250,3 +252,21 @@ class BigQueryDBStream(dbstream.DBStream):
     def drop_schema(self, schema_name):
         con = self.connection()
         con.delete_dataset(dataset=con.project + "." + schema_name, delete_contents=True, not_found_ok=True)
+
+    @staticmethod
+    def build_pydatasource_view(query_string):
+        return """
+                    drop view if exists {{ table_name }};
+                    create view {{ table_name }} as (
+                    %s
+                    );
+                    """ % query_string
+
+    @staticmethod
+    def build_pydatasource_table(query_string):
+        return """
+                    drop table if exists {{ table_name }};
+                    create table {{ table_name }} as (
+                    %s
+                    );
+                    """ % query_string
